@@ -1,3 +1,3 @@
 from ._image import Preprocessing
-from ._image import load_and_preprocess_image
+from ._image import preprocess_image
 from ._model import make_open_nsfw_model
